Index: components/safe_json/json_sanitizer_unittest.cc |
diff --git a/components/safe_json/json_sanitizer_unittest.cc b/components/safe_json/json_sanitizer_unittest.cc |
index 7caa0992e2b607b93d101a78784fc0a313f39111..aac3a494020703fdf8706428a4c4ce0858be3620 100644 |
--- a/components/safe_json/json_sanitizer_unittest.cc |
+++ b/components/safe_json/json_sanitizer_unittest.cc |
@@ -133,13 +133,13 @@ TEST_F(JsonSanitizerTest, Json) { |
} |
TEST_F(JsonSanitizerTest, Nesting) { |
- // 99 nested arrays are fine. |
- std::string nested(99u, '['); |
- nested.append(99u, ']'); |
+ // 199 nested arrays are fine. |
+ std::string nested(199u, '['); |
+ nested.append(199u, ']'); |
CheckSuccess(nested); |
- // 100 nested arrays is too much. |
- CheckError(std::string(100u, '[') + std::string(100u, ']')); |
+ // 200 nested arrays is too much. |
+ CheckError(std::string(200u, '[') + std::string(200u, ']')); |
} |
TEST_F(JsonSanitizerTest, Unicode) { |